# SAP (SuccessFactors) Connector
> Get software and technology solutions from SAP, the leader in business applications.  Run simple with the best in cloud, analytics, mobile and IT solutions.

🔗 https://www.sap.com/


| Actions |
| ------- |
| [**Pull jobs**](docs/pull_jobs.md) |
| [**Push profile**](docs/push_profile.md) |